0.9.9 API documentation: GLM_GTX_matrix_query

| 0.9.9 API documentation

- Main Page
- Modules
- Files

Functions
GLM_GTX_matrix_query
Experimental extensions

Include <glm/gtx/matrix_query.hpp> to use the features of this extension. More...

## Functions
template<length_t C, length_t R, typename T , qualifier Q, template< length_t, length_t, typename, qualifier > class matType>
GLM_FUNC_DECL bool | isIdentity (matType< C, R, T, Q > const &m, T const &epsilon)
| Return whether a matrix is an identity matrix. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL bool | isNormalized (mat< 2, 2, T, Q > const &m, T const &epsilon)
| Return whether a matrix is a normalized matrix. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL bool | isNormalized (mat< 3, 3, T, Q > const &m, T const &epsilon)
| Return whether a matrix is a normalized matrix. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL bool | isNormalized (mat< 4, 4, T, Q > const &m, T const &epsilon)
| Return whether a matrix is a normalized matrix. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL bool | isNull (mat< 2, 2, T, Q > const &m, T const &epsilon)
| Return whether a matrix a null matrix. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL bool | isNull (mat< 3, 3, T, Q > const &m, T const &epsilon)
| Return whether a matrix a null matrix. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL bool | isNull (mat< 4, 4, T, Q > const &m, T const &epsilon)
| Return whether a matrix is a null matrix. More...
template<length_t C, length_t R, typename T , qualifier Q, template< length_t, length_t, typename, qualifier > class matType>
GLM_FUNC_DECL bool | isOrthogonal (matType< C, R, T, Q > const &m, T const &epsilon)
| Return whether a matrix is an orthonormalized matrix. More...

## Detailed Description

Include <glm/gtx/matrix_query.hpp> to use the features of this extension.

Query to evaluate matrix properties

## Function Documentation

GLM_FUNC_DECL bool glm::isIdentity | ( | matType< C, R, T, Q > const & | m,
|  | T const & | epsilon
| ) |  |

Return whether a matrix is an identity matrix.

From GLM_GTX_matrix_query extension.

GLM_FUNC_DECL bool glm::isNormalized | ( | mat< 2, 2, T, Q > const & | m,
|  | T const & | epsilon
| ) |  |

Return whether a matrix is a normalized matrix.

From GLM_GTX_matrix_query extension.

GLM_FUNC_DECL bool glm::isNormalized | ( | mat< 3, 3, T, Q > const & | m,
|  | T const & | epsilon
| ) |  |

Return whether a matrix is a normalized matrix.

From GLM_GTX_matrix_query extension.

GLM_FUNC_DECL bool glm::isNormalized | ( | mat< 4, 4, T, Q > const & | m,
|  | T const & | epsilon
| ) |  |

Return whether a matrix is a normalized matrix.

From GLM_GTX_matrix_query extension.

GLM_FUNC_DECL bool glm::isNull | ( | mat< 2, 2, T, Q > const & | m,
|  | T const & | epsilon
| ) |  |

Return whether a matrix a null matrix.

From GLM_GTX_matrix_query extension.

GLM_FUNC_DECL bool glm::isNull | ( | mat< 3, 3, T, Q > const & | m,
|  | T const & | epsilon
| ) |  |

Return whether a matrix a null matrix.

From GLM_GTX_matrix_query extension.

GLM_FUNC_DECL bool glm::isNull | ( | mat< 4, 4, T, Q > const & | m,
|  | T const & | epsilon
| ) |  |

Return whether a matrix is a null matrix.

From GLM_GTX_matrix_query extension.

GLM_FUNC_DECL bool glm::isOrthogonal | ( | matType< C, R, T, Q > const & | m,
|  | T const & | epsilon
| ) |  |

Return whether a matrix is an orthonormalized matrix.

From GLM_GTX_matrix_query extension.